@@ -92,11 +92,7 @@ sub evaluate {
   my $error = $@;
 
   if ($error) {
-    my $throw;
-    $throw = $self->throw;
-    $throw->name('on.evaluate');
-    $throw->message($error);
-    $throw->error;
+    $self->throw('error_on_evaluate', $error)->error;
   }
 
   return $self->stash(evaluation => [
@@ -209,8 +205,18 @@ sub set {
   return $evaluation->[1];
 }
 
-1;
+# ERRORS
 
+sub error_on_evaluate {
+  my ($self, $error) = @_;
+
+  return {
+    name => 'on.evaluate',
+    message => $error,
+  };
+}
+
+1;
 
 
 
@@ -403,7 +409,7 @@ I<Since C<0.01>>
 
   my $evaluate = $replace->evaluate;
 
-  # Exception! Venus::Replace::Error (isa Venus::Error)
+  # Exception! (isa Venus::Replace::Error) (see error_on_evaluate)
 
 =back
 
@@ -663,6 +669,36 @@ I<Since C<0.01>>
 
 =cut
 
+=head1 ERRORS
+
+This package may raise the following errors:
+
+=cut
+
+=over 4
+
+=item error: C<error_on_evaluate>
+
+This package may raise an error_on_evaluate exception.
+
+B<example 1>
+
+  # given: synopsis;
+
+  my @args = ('Exception!');
+
+  my $error = $replace->throw('error_on_evaluate', @args)->catch('error');
+
+  # my $name = $error->name;
+
+  # "on_evaluate"
+
+  # my $message = $error->message;
+
+  # "Exception!"
+
+=back
+
 =head1 OPERATORS
 
 This package overloads the following operators:
